@@ -1,19 +1,17 @@
 package Sample::Employee;
-use base qw/Jifty::DBI::Record/;
-
-package Sample::Employee::Schema;
 use Jifty::DBI::Schema;
+use Jifty::DBI::Record schema {
 
 column dexterity => type is 'integer';
 column name      => type is 'varchar';
+column label     => type is 'varchar';
+column type      => type is 'varchar';
 
-
+};
 
 package Sample::Address;
-use base qw/Jifty::DBI::Record/;
-
-package Sample::Address::Schema;
 use Jifty::DBI::Schema;
+use Jifty::DBI::Record schema {
 
 column employee_id =>
   refers_to Sample::Employee;
@@ -25,4 +23,6 @@ column name =>
 column phone =>
   type is 'varchar';
 
+};
+
 1;
